

## This is TCL Code!!
puts "Hello world!"

## Location of this current script
set location [file dirname [file normalize [info script]]]

## Configure RC
#######################

set_attribute hdl_track_filename_row_col true
set_attribute enc_user_constraint_file ../encounter_configuration.tcl


## Read Libraries
#######################

#### Read Physical Definitions
set_attribute lef_library [list \
    $::env(UMC_HOME)/65nm-stdcells/lef/tf/uk65lscllmvbbr_9m2t1f.lef \
    $::env(UMC_HOME)/65nm-stdcells/lef/uk65lscllmvbbr.lef \
    $::env(UMC_HOME)/65nm-pads/lef/u065gioll18gpir_9m2t2h.lef]


#### Read Timing Libraries
set_attribute library [list  \
    $::env(UMC_HOME)/65nm-stdcells/synopsys/uk65lscllmvbbr_090c125_wc.lib \
    $::env(UMC_HOME)/65nm-pads/synopsys/u065gioll18gpir_wc.lib \
]

## Avoid some cells, just ignore for now
set_attribute avoid true [find -libcell CK*]
set_attribute avoid true [find -libcell *M16RA]
set_attribute avoid true [find -libcell *M22RA]



check_library

## Read design
########################
set_attribute hdl_language {sv}

read_hdl -sv [list ../../sources/counter_top.v  ../../sources/counter.v]

#read_hdl -define ASIC  -sv [list /home/rleys/bwsync/adl/ss15/dds/vorlesung/28-04-15-introhdl/code/counter_top.v  /home/rleys/bwsync/adl/ss15/dds/vorlesung/28-04-15-introhdl/code/counter.v]

## Elaborate
#################
elaborate



## Read constraints
#########################
read_sdc ../../sources/constraints.sdc


## Cost group
set all_regs [find / -instance instances_seq/*]
define_cost_group -name C2C
path_group -from $all_regs -to $all_regs -group C2C -name C2C

## Configure Synthesis
######################

# Physical Synthesis Mode -> no wire delay
set_attribute interconnect_mode ple / 

## Synthesise to gates
############################

if {[file exists floorplan.def]} {

    read_def floorplan.def

    synthesize -to_placed -effort medium
    synthesize -to_placed -effort medium -incr

} else {

    ## To Mapped
    synthesize -to_mapped -effort medium

    ## Incr Optimisation
    synthesize -to_mapped -effort medium -incr
    synthesize -to_mapped -effort medium -incr

}








## Write report and data
################################
exec mkdir -p netlist
write_hdl > netlist/counter_top.gtl.v
