

// tb_top is a conventional name
module tb_top;

	// Parameter
	localparam SIZE = 16;

	// Wiring
	//--------------------
	logic clk;
	logic res_n;

	logic hold;
	logic clear;

	logic [SIZE-1:0] value;


	// Instance: Device Under Test (dut)
	//---------------
	counter_top   dut (
		.clk(clk),
		.res_n(res_n),

		.hold(hold),
		.clear(clear),

		.value(value)

	);

	// Clock and Reset
	//----------------------
	
	// Reset
	initial 
	begin
		clk = 0;
		res_n = 0;

		// Functional inital values
		hold = 0;
		clear = 0;

		// No reset for value, its reset is in the logic

		// Wait and release reset
		#50ns res_n = 1;

	end

	// Clock
	always 
	begin 
		#5ns clk <= ~clk;
	end

	// Test
	//--------------------
	initial
	begin

		// Wait for Reset to be released
		// Sync on clock one time
		wait (res_n==1);
		@(posedge clk);
		@(negedge clk);
		@(negedge clk);

		// 
		clear = 1;
		@(negedge clk);
		@(negedge clk);

		clear = 0;
		@(negedge clk);
		@(negedge clk);

		hold = 1;
		@(negedge clk);
		@(negedge clk);

		hold = 0;
		@(negedge clk);
		@(negedge clk);


		#2000ns $finish();

	end


endmodule
